@@ -1,9 +1,12 @@
 import ctypes
+import logging
 
 from .bass_module import bass_module, Bass
 from .bass_module import func_type
 from .datatypes import QWORD, HSTREAM, HANDLE
 
+log = logging.getLogger(__name__)
+
 BASS_StreamCreateFile = func_type(
     HSTREAM,
     ctypes.c_bool,
@@ -22,8 +25,13 @@ BASS_StreamGetFilePosition = func_type(
     ctypes.c_ulong)(('BASS_StreamGetFilePosition', bass_module))
 
 
+
+
 class BassStream:
 
+    DEBUG_BASS_STREAM = False
+    DEBUG_OPEN_HANDLES = []
+
     @classmethod
     def CreateFile(cls, mem, file, offset=0, length=0, flags=0):
         """
@@ -38,13 +46,31 @@ class BassStream:
         Returns:
 
         """
-        handle = BASS_StreamCreateFile(mem, file, offset, length, flags)
 
+        handle = BASS_StreamCreateFile(mem, file, offset, length, flags)
+        log.debug("Opened handle to %s with %s", file, handle)
         if handle == 0:
             Bass.RaiseError(f"file={file!r}")
 
+        if cls.DEBUG_BASS_STREAM is True:
+            cls.DEBUG_OPEN_HANDLES.append(handle)
+
         return handle
 
     @classmethod
     def Free(cls, handle: HANDLE):
-        return BASS_StreamFree(handle)
\ No newline at end of file
+        """
+            Free a stream handle.   Fails silently if there is an issue freeing
+            the given handle
+
+        :param handle: The BASS stream handle to free
+        :return:
+        """
+        global DEBUG_BASS_STREAM, DEBUG_OPEN_HANDLES
+
+        log.debug("Freeing handle %s", handle)
+        retval = BASS_StreamFree(handle)
+        if cls.DEBUG_BASS_STREAM is True:
+            cls.DEBUG_OPEN_HANDLES.remove(handle)
+
+        return retval
\ No newline at end of file
